@@ -19,9 +19,13 @@ class TCPServerHandler(socketserver.BaseRequestHandler):
         else:
             try:
                 execute_str = json.loads(command_string)
-                for execute_function, execute_return in execute_action(execute_str).items():
-                    socket.sendto(str(execute_return).encode("utf-8"), self.client_address)
-                    socket.sendto("\n".encode("utf-8"), self.client_address)
+                if execute_str is not None:
+                    for execute_function, execute_return in execute_action(execute_str).items():
+                        socket.sendto(str(execute_return).encode("utf-8"), self.client_address)
+                        socket.sendto("\n".encode("utf-8"), self.client_address)
+                    else:
+                        socket.sendto("No_Return_Data".encode("utf-8"), self.client_address)
+                        socket.sendto("\n".encode("utf-8"), self.client_address)
                 socket.sendto("Return_Data_Over_JE".encode("utf-8"), self.client_address)
                 socket.sendto("\n".encode("utf-8"), self.client_address)
             except Exception as error:
